SchemaSpy - Table gnss_data.public.apr_coords

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.apr_coords | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 3 |  |  |  |  |
stations.NetworkCode | apr_coords_NetworkCode_fkey R
StationCode | varchar | 4 |  |  |  |  |
stations.StationCode | apr_coords_NetworkCode_fkey R
Year | timestamp | 29,6 |  |  |  |  |  |
DOY | timestamp | 29,6 |  |  |  |  |  |
FYear | numeric | 131089 | √ |  | null |  |  |
x | numeric | 131089 | √ |  | null |  |  |
y | numeric | 131089 | √ |  | null |  |  |
z | numeric | 131089 | √ |  | null |  |  |
sn | numeric | 131089 | √ |  | null |  |  |
se | numeric | 131089 | √ |  | null |  |  |
su | numeric | 131089 | √ |  | null |  |  |
ReferenceFrame | varchar | 20 | √ |  | null |  |  |
Table contained 0 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: